-- encoding=utf-8

print('Testing', text1, text2, text3)
assert(text1 == 'hi')
assert(text2 == 'hé')
assert(text3 == '狗')

text4 = '猫'

print(num1, type(num1))
assert(num1 == 42)
num2 = 42

assert(bool1)
assert(not bool2)